Enum AliasTarget
pub enum AliasTarget {
MastRoot(Span<Word>),
Path(Span<Arc<Path>>),
}Expand description
A fully-qualified external item that is the target of an alias
Variants
MastRoot(Span<Word>)
An alias of the procedure whose root is the given digest
This target type is only valid for procedures.
Corresponds to InvocationTarget::MastRoot
Path(Span<Arc<Path>>)
An alias of an item using a path that may need to be resolved relative to the importing module.
Corresponds to InvocationTarget::Path
Implementations
impl AliasTarget
impl AliasTarget
pub fn unwrap_path(&self) -> &Arc<Path>