Instruction

Enum Instruction 

pub enum Instruction {
Show 238 variants Nop, Assert, AssertWithError(Immediate<Arc<str>>), AssertEq, AssertEqWithError(Immediate<Arc<str>>), AssertEqw, AssertEqwWithError(Immediate<Arc<str>>), Assertz, AssertzWithError(Immediate<Arc<str>>), Add, AddImm(Immediate<Felt>), Sub, SubImm(Immediate<Felt>), Mul, MulImm(Immediate<Felt>), Div, DivImm(Immediate<Felt>), Neg, ILog2, Inv, Incr, Pow2, Exp, ExpImm(Immediate<Felt>), ExpBitLength(u8), Not, And, Or, Xor, Eq, EqImm(Immediate<Felt>), Neq, NeqImm(Immediate<Felt>), Eqw, Lt, Lte, Gt, Gte, IsOdd, Ext2Add, Ext2Sub, Ext2Mul, Ext2Div, Ext2Neg, Ext2Inv, U32Test, U32TestW, U32Assert, U32AssertWithError(Immediate<Arc<str>>), U32Assert2, U32Assert2WithError(Immediate<Arc<str>>), U32AssertW, U32AssertWWithError(Immediate<Arc<str>>), U32Split, U32Cast, U32WrappingAdd, U32WrappingAddImm(Immediate<u32>), U32OverflowingAdd, U32OverflowingAddImm(Immediate<u32>), U32WideningAdd, U32WideningAddImm(Immediate<u32>), U32OverflowingAdd3, U32WideningAdd3, U32WrappingAdd3, U32WrappingSub, U32WrappingSubImm(Immediate<u32>), U32OverflowingSub, U32OverflowingSubImm(Immediate<u32>), U32WrappingMul, U32WrappingMulImm(Immediate<u32>), U32WideningMul, U32WideningMulImm(Immediate<u32>), U32WideningMadd, U32WrappingMadd, U32Div, U32DivImm(Immediate<u32>), U32Mod, U32ModImm(Immediate<u32>), U32DivMod, U32DivModImm(Immediate<u32>), U32And, U32Or, U32Xor, U32Not, U32Shr, U32ShrImm(Immediate<u8>), U32Shl, U32ShlImm(Immediate<u8>), U32Rotr, U32RotrImm(Immediate<u8>), U32Rotl, U32RotlImm(Immediate<u8>), U32Popcnt, U32Ctz, U32Clz, U32Clo, U32Cto, U32Lt, U32Lte, U32Gt, U32Gte, U32Min, U32Max, Drop, DropW, PadW, Dup0, Dup1, Dup2, Dup3, Dup4, Dup5, Dup6, Dup7, Dup8, Dup9, Dup10, Dup11, Dup12, Dup13, Dup14, Dup15, DupW0, DupW1, DupW2, DupW3, Swap1, Swap2, Swap3, Swap4, Swap5, Swap6, Swap7, Swap8, Swap9, Swap10, Swap11, Swap12, Swap13, Swap14, Swap15, SwapW1, SwapW2, SwapW3, SwapDw, MovUp2, MovUp3, MovUp4, MovUp5, MovUp6, MovUp7, MovUp8, MovUp9, MovUp10, MovUp11, MovUp12, MovUp13, MovUp14, MovUp15, MovUpW2, MovUpW3, MovDn2, MovDn3, MovDn4, MovDn5, MovDn6, MovDn7, MovDn8, MovDn9, MovDn10, MovDn11, MovDn12, MovDn13, MovDn14, MovDn15, MovDnW2, MovDnW3, Reversew, Reversedw, CSwap, CSwapW, CDrop, CDropW, Push(Immediate<PushValue>), PushSlice(Immediate<WordValue>, Range<usize>), PushFeltList(Vec<Felt>), Locaddr(Immediate<u16>), Sdepth, Caller, Clk, MemLoad, MemLoadImm(Immediate<u32>), MemLoadWBe, MemLoadWBeImm(Immediate<u32>), MemLoadWLe, MemLoadWLeImm(Immediate<u32>), LocLoad(Immediate<u16>), LocLoadWBe(Immediate<u16>), LocLoadWLe(Immediate<u16>), MemStore, MemStoreImm(Immediate<u32>), MemStoreWBe, MemStoreWBeImm(Immediate<u32>), MemStoreWLe, MemStoreWLeImm(Immediate<u32>), LocStore(Immediate<u16>), LocStoreWBe(Immediate<u16>), LocStoreWLe(Immediate<u16>), MemStream, AdvPipe, AdvPush(Immediate<u8>), AdvLoadW, SysEvent(SystemEventNode), Hash, HMerge, HPerm, MTreeGet, MTreeSet, MTreeMerge, MTreeVerify, MTreeVerifyWithError(Immediate<Arc<str>>), CryptoStream, FriExt2Fold4, HornerBase, HornerExt, EvalCircuit, LogPrecompile, Exec(InvocationTarget), Call(InvocationTarget), SysCall(InvocationTarget), DynExec, DynCall, ProcRef(InvocationTarget), Debug(DebugOptions), DebugVar(DebugVarInfo), Emit, EmitImm(Immediate<Felt>), Trace(Immediate<u32>),
}
Represents the set of primitive instructions in Miden Assembly syntax.

NOTE: For control flow instructions, see crate::ast::Op.

Variants



Nop



Assert



AssertWithError(Immediate<Arc<str>>)



AssertEq



AssertEqWithError(Immediate<Arc<str>>)



AssertEqw



AssertEqwWithError(Immediate<Arc<str>>)



Assertz



AssertzWithError(Immediate<Arc<str>>)



Add



AddImm(Immediate<Felt>)



Sub



SubImm(Immediate<Felt>)



Mul



MulImm(Immediate<Felt>)



Div



DivImm(Immediate<Felt>)



Neg



ILog2



Inv



Incr



Pow2



Exp



ExpImm(Immediate<Felt>)



ExpBitLength(u8)



Not



And



Or



Xor



Eq



EqImm(Immediate<Felt>)



Neq



NeqImm(Immediate<Felt>)



Eqw



Lt



Lte



Gt



Gte



IsOdd



Ext2Add



Ext2Sub



Ext2Mul



Ext2Div



Ext2Neg



Ext2Inv



U32Test



U32TestW



U32Assert



U32AssertWithError(Immediate<Arc<str>>)



U32Assert2



U32Assert2WithError(Immediate<Arc<str>>)



U32AssertW



U32AssertWWithError(Immediate<Arc<str>>)



U32Split



U32Cast



U32WrappingAdd



U32WrappingAddImm(Immediate<u32>)



U32OverflowingAdd



U32OverflowingAddImm(Immediate<u32>)



U32WideningAdd



U32WideningAddImm(Immediate<u32>)



U32OverflowingAdd3



U32WideningAdd3



U32WrappingAdd3



U32WrappingSub



U32WrappingSubImm(Immediate<u32>)



U32OverflowingSub



U32OverflowingSubImm(Immediate<u32>)



U32WrappingMul



U32WrappingMulImm(Immediate<u32>)



U32WideningMul



U32WideningMulImm(Immediate<u32>)



U32WideningMadd



U32WrappingMadd



U32Div



U32DivImm(Immediate<u32>)



U32Mod



U32ModImm(Immediate<u32>)



U32DivMod



U32DivModImm(Immediate<u32>)



U32And



U32Or



U32Xor



U32Not



U32Shr



U32ShrImm(Immediate<u8>)



U32Shl



U32ShlImm(Immediate<u8>)



U32Rotr



U32RotrImm(Immediate<u8>)



U32Rotl



U32RotlImm(Immediate<u8>)



U32Popcnt



U32Ctz



U32Clz



U32Clo



U32Cto



U32Lt



U32Lte



U32Gt



U32Gte



U32Min



U32Max



Drop



DropW



PadW



Dup0



Dup1



Dup2



Dup3



Dup4



Dup5



Dup6



Dup7



Dup8



Dup9



Dup10



Dup11



Dup12



Dup13



Dup14



Dup15



DupW0



DupW1



DupW2



DupW3



Swap1



Swap2



Swap3



Swap4



Swap5



Swap6



Swap7



Swap8



Swap9



Swap10



Swap11



Swap12



Swap13



Swap14



Swap15



SwapW1



SwapW2



SwapW3



SwapDw



MovUp2



MovUp3



MovUp4



MovUp5



MovUp6



MovUp7



MovUp8



MovUp9



MovUp10



MovUp11



MovUp12



MovUp13



MovUp14



MovUp15



MovUpW2



MovUpW3



MovDn2



MovDn3



MovDn4



MovDn5



MovDn6



MovDn7



MovDn8



MovDn9



MovDn10



MovDn11



MovDn12



MovDn13



MovDn14



MovDn15



MovDnW2



MovDnW3



Reversew



Reversedw



CSwap



CSwapW



CDrop



CDropW



Push(Immediate<PushValue>)



PushSlice(Immediate<WordValue>, Range<usize>)



PushFeltList(Vec<Felt>)



Locaddr(Immediate<u16>)



Sdepth



Caller



Clk



MemLoad



MemLoadImm(Immediate<u32>)



MemLoadWBe



MemLoadWBeImm(Immediate<u32>)



MemLoadWLe



MemLoadWLeImm(Immediate<u32>)



LocLoad(Immediate<u16>)



LocLoadWBe(Immediate<u16>)



LocLoadWLe(Immediate<u16>)



MemStore



MemStoreImm(Immediate<u32>)



MemStoreWBe



MemStoreWBeImm(Immediate<u32>)



MemStoreWLe



MemStoreWLeImm(Immediate<u32>)



LocStore(Immediate<u16>)



LocStoreWBe(Immediate<u16>)



LocStoreWLe(Immediate<u16>)



MemStream



AdvPipe



AdvPush(Immediate<u8>)



AdvLoadW



SysEvent(SystemEventNode)



Hash



HMerge



HPerm



MTreeGet



MTreeSet



MTreeMerge



MTreeVerify



MTreeVerifyWithError(Immediate<Arc<str>>)



CryptoStream



FriExt2Fold4



HornerBase



HornerExt



EvalCircuit



LogPrecompile



Exec(InvocationTarget)



Call(InvocationTarget)



SysCall(InvocationTarget)



DynExec



DynCall



ProcRef(InvocationTarget)



Debug(DebugOptions)



DebugVar(DebugVarInfo)



Emit



EmitImm(Immediate<Felt>)



Trace(Immediate<u32>)

Implementations

Source

impl Instruction

pub const fn has_textual_representation(&self) -> bool

Returns true if this instruction has a textual representation in Miden Assembly.

Some instructions (like DebugVar) are compiler-internal and have no surface syntax. They should be skipped during pretty-printing.