Enum InvocationTarget
pub enum InvocationTarget {
MastRoot(Span<Word>),
Symbol(Ident),
Path(Span<Arc<Path>>),
}Expand description
Describes targets of exec, call, and syscall instructions.
A label of an invoked procedure must comply with the following rules:
- It can be a hexadecimal string representing a MAST root digest ([Word]). In this case, the label must start with “0x” and must be followed by a valid hexadecimal string representation of an [Word].
- It can contain a single procedure name. In this case, the label must comply with procedure name rules.
- It can contain module name followed by procedure name (e.g., “module::procedure”). In this case both module and procedure name must comply with relevant name rules.
All other combinations will result in an error.
Variants
MastRoot(Span<Word>)
An absolute procedure reference, but opaque in that we do not know where the callee is defined. However, it does not actually matter, we consider such references to be a priori valid.
Symbol(Ident)
A locally-defined procedure.
Path(Span<Arc<Path>>)
An externally-defined procedure.
Implementations
impl InvocationTarget
impl InvocationTarget
pub fn unwrap_path(&self) -> &Path