Enum Meta
pub enum Meta {
Unit,
List(Vec<MetaExpr>),
KeyValue(BTreeMap<Ident, MetaExpr>),
}Expand description
Represents the metadata provided as arguments to an attribute.
Variants
Unit
Represents empty metadata, e.g. @foo
List(Vec<MetaExpr>)
A list of metadata expressions, e.g. @foo(a, "some text", 0x01)
The list should always have at least one element, and this is guaranteed by the parser.
KeyValue(BTreeMap<Ident, MetaExpr>)
A set of uniquely-named metadata expressions, e.g. @foo(letter = a, text = "some text")
The set should always have at least one key-value pair, and this is guaranteed by the parser.
Implementations
impl Meta
impl Meta
pub fn borrow(&self) -> Option<BorrowedMeta<'_>>
pub fn borrow(&self) -> Option<BorrowedMeta<'_>>
Borrow the metadata without unwrapping the specific type
Returns None if there is no meaningful metadata