Enum TypeExpr
pub enum TypeExpr {
Primitive(Span<Type>),
Ptr(PointerType),
Array(ArrayType),
Struct(StructType),
Ref(Span<Arc<Path>>),
}Expand description
A syntax-level type expression (i.e. primitive type, reference to nominal type, etc.)
Variants
Primitive(Span<Type>)
A primitive integral type, e.g. i1, u16
Ptr(PointerType)
A pointer type expression, e.g. *u8
Array(ArrayType)
An array type expression, e.g. [u8; 32]
Struct(StructType)
A struct type expression, e.g. struct { a: u32 }
Ref(Span<Arc<Path>>)
A reference to a type aliased by name, e.g. Foo
Implementations
impl TypeExpr
impl TypeExpr
pub fn set_name(&mut self, name: Ident)
pub fn set_name(&mut self, name: Ident)
Set the name associated with this type expression, if applicable.
Currently this just sets the name of struct types, but if we add other types with names in the future, we can support them here.
pub fn references(&self) -> Vec<Span<Arc<Path>>>
pub fn references(&self) -> Vec<Span<Arc<Path>>>
Get any references to other types present in this expression
pub fn resolve_type<E, R>(&self, resolver: &mut R) -> Result<Option<Type>, E>where
R: TypeResolver<E> + ?Sized,
pub fn resolve_type<E, R>(&self, resolver: &mut R) -> Result<Option<Type>, E>where
R: TypeResolver<E> + ?Sized,
Resolve this type expression to a concrete type, using resolver