Struct AttributeSet
pub struct AttributeSet { /* private fields */ }Expand description
An AttributeSet provides storage and access to all of the attributes attached to a Miden Assembly item, e.g. procedure definition.
Attributes are unique by name, so if you attempt to add multiple attributes with the same name, the last write wins. In Miden Assembly syntax, multiple key-value attributes are merged automatically, and a syntax error is only generated when keys conflict. All other attribute types produce an error if they are declared multiple times on the same item.
Implementations
impl AttributeSet
impl AttributeSet
pub fn new<I>(attrs: I) -> AttributeSetwhere
I: IntoIterator<Item = Attribute>,
pub fn new<I>(attrs: I) -> AttributeSetwhere
I: IntoIterator<Item = Attribute>,
Create a new AttributeSet from attrs
If the input attributes have duplicate entries for the same name, only one will be selected, but it is unspecified which.
pub fn get(&self, name: impl AsRef<str>) -> Option<&Attribute>
pub fn get(&self, name: impl AsRef<str>) -> Option<&Attribute>
Get the attribute named name, if one is present.
pub fn get_mut(&mut self, name: impl AsRef<str>) -> Option<&mut Attribute>
pub fn get_mut(&mut self, name: impl AsRef<str>) -> Option<&mut Attribute>
Get a mutable reference to the attribute named name, if one is present.
pub fn iter_mut(&mut self) -> IterMut<'_, Attribute>
pub fn iter_mut(&mut self) -> IterMut<'_, Attribute>
Get a mutable iterator over the attributes in this set
pub fn insert(&mut self, attr: Attribute) -> bool
pub fn insert(&mut self, attr: Attribute) -> bool
Insert attr in the attribute set, replacing any existing attribute with the same name
Returns true if the insertion was new, or false if the insertion replaced an existing entry.
pub fn insert_new(&mut self, attr: Attribute) -> Result<(), Attribute>
pub fn insert_new(&mut self, attr: Attribute) -> Result<(), Attribute>
Insert attr in the attribute set, but only if there is no existing attribute with the same
name.
Returns Err with attr if there is already an existing attribute with the same name.
pub fn remove(&mut self, name: impl AsRef<str>) -> Option<Attribute>
pub fn remove(&mut self, name: impl AsRef<str>) -> Option<Attribute>
Removes the attribute named name, if present.
pub fn entry(&mut self, key: Ident) -> AttributeSetEntry<'_>
pub fn entry(&mut self, key: Ident) -> AttributeSetEntry<'_>
Gets the given key’s corresponding entry in the set for in-place modfication
pub fn clear(&mut self)
pub fn clear(&mut self)
Clear all attributes from the set