LocalSymbolResolver

Struct LocalSymbolResolver 

pub struct LocalSymbolResolver { /* private fields */ }
A resolver for symbol references in the context of some module.

This resolver does not attempt to resolve external references, aside from expanding any uses of imports in an external path.

This is used as a low-level symbol resolution primitive in the linker as well.

Implementations



impl LocalSymbolResolver

pub fn new<S>( symbols: S, source_manager: Arc<dyn SourceManager>, ) -> LocalSymbolResolver
where S: SymbolTable,

Create a new resolver using the provided SymbolTable and SourceManager.

pub fn expand<F>( get_import: F, path: Span<&Path>, source_manager: &dyn SourceManager, ) -> Result<SymbolResolution, SymbolResolutionError>
where F: Fn(&str) -> Option<AliasTarget>,

Expand path using get_import to resolve a raw symbol name to an import in the current symbol resolution context.

Uses the provided SourceManager to emit errors that are discovered during expansion.

pub fn source_manager(&self) -> Arc<dyn SourceManager>

pub fn resolve( &self, name: Span<&str>, ) -> Result<SymbolResolution, SymbolResolutionError>

Try to resolve name to an item, either local or external

See SymbolTable::get for details.

pub fn resolve_path( &self, path: Span<&Path>, ) -> Result<SymbolResolution, SymbolResolutionError>

Try to resolve path to an item, either local or external

pub fn get_item_name(&self, index: ItemIndex) -> Ident

Get the name of the item at index

This is guaranteed to resolve if index is valid, and will panic if not.