Struct MetaList
pub struct MetaList {
pub span: SourceSpan,
pub name: Ident,
pub items: Vec<MetaExpr>,
}Expand description
Represents the metadata of a named list crate::ast::Attribute, i.e. @name(item0, .., itemN)
Fields
span: SourceSpanname: IdentThe identifier used as the name of this attribute
items: Vec<MetaExpr>The list of items representing the value of this attribute - will always contain at least one element when parsed.
Implementations
impl MetaList
impl MetaList
pub fn new<I>(name: Ident, items: I) -> MetaListwhere
I: IntoIterator<Item = MetaExpr>,
pub fn with_span(self, span: SourceSpan) -> MetaList
pub fn as_mut_slice(&mut self) -> &mut [MetaExpr]
pub fn as_mut_slice(&mut self) -> &mut [MetaExpr]
Get the metadata list as a mutable slice