Struct PathBuf
pub struct PathBuf { /* private fields */ }Expand description
Path to an item in a library, i.e. module, procedure, constant or type.
Implementations
impl PathBuf
Constructors
impl PathBuf
Constructors
pub fn with_capacity(capacity: usize) -> PathBuf
pub fn with_capacity(capacity: usize) -> PathBuf
Get an empty PathBuf with capacity bytes allocated for the underlying path storage
pub fn new<S>(source: &S) -> Result<PathBuf, PathError>
pub fn new<S>(source: &S) -> Result<PathBuf, PathError>
Returns a new path created from the provided source.
A path consists of at list of components separated by :: delimiter. A path must contain
at least one component.
Errors
Returns an error if:
- The path is empty.
- Any component of the path is empty.
- Any component is not a valid identifier (quoted or unquoted) in Miden Assembly syntax,
i.e. starts with an ASCII alphabetic character, contains only printable ASCII characters,
except for
::, which must only be used as a path separator.
pub fn into_boxed_path(self) -> Box<Path>
pub fn into_boxed_path(self) -> Box<Path>
Convert this mutable PathBuf into an owned, read-only alloc::boxed::Box<Path>
impl PathBuf
Mutation
impl PathBuf
Mutation
pub fn set_parent<P>(&mut self, parent: &P)
pub fn set_parent<P>(&mut self, parent: &P)
Overrides the parent prefix of this path.
The parent prefix is the part of the path consisting of all components but the last one.
If there is only a single component in self, this function is equivalent to appending
self to parent.
pub fn push<P>(&mut self, path: &P)
pub fn push<P>(&mut self, path: &P)
Extends self with path
If path is absolute, it replaces the current path.
This function ensures that the joined path correctly delimits each path component, and that each component is in canonical form.
pub fn push_component<S>(&mut self, component: &S)
pub fn push_component<S>(&mut self, component: &S)
Extends self with component.
Unlike Self::push, which appends another Path to the buffer - this method appends the
given string as a single path component, ensuring that the content is quoted properly if
needed.
If :: is pushed, it is treated as a literal root component (i.e. it makes the path
absolute). On a non-empty PathBuf, this has the effect of clearing the path, similar to
what happens if you call PathBuf::push with an absolute path.
Pushing components using this method guarantees they are in canonical form.
pub fn pop(&mut self) -> bool
pub fn pop(&mut self) -> bool
Truncates self to Path::parent.
Returns false if self.parent() is None, otherwise true.
Methods from Deref<Target = Path>
pub const MAX_COMPONENT_LENGTH: usize
pub const EMPTY: &'static Path
pub const KERNEL_PATH: &'static str = "$kernel"
pub const ABSOLUTE_KERNEL_PATH: &'static str = "::$kernel"
pub const KERNEL: &'static Path
pub const EXEC_PATH: &'static str = "$exec"
pub const ABSOLUTE_EXEC_PATH: &'static str = "::$exec"
pub const EXEC: &'static Path
pub fn as_str(&self) -> &str
pub fn to_path_buf(&self) -> PathBuf
pub fn to_path_buf(&self) -> PathBuf
pub fn is_absolute(&self) -> bool
pub fn is_absolute(&self) -> bool
Returns true if this path is an absolute path
pub fn to_absolute(&self) -> Cow<'_, Path>
pub fn to_absolute(&self) -> Cow<'_, Path>
Make this path absolute, if not already
NOTE: This does not resolve the path, it simply ensures the path has the root prefix
pub fn to_relative(&self) -> &Path
pub fn to_relative(&self) -> &Path
Strip the root prefix from this path, if it has one.
pub fn components(&self) -> Iter<'_> ⓘ
pub fn components(&self) -> Iter<'_> ⓘ
Returns an iterator over all components of the path.
pub fn first(&self) -> Option<&str>
pub fn first(&self) -> Option<&str>
Get the first non-root component of this path as a str
Returns None if the path is empty, or consists only of the root prefix.
pub fn last(&self) -> Option<&str>
pub fn last(&self) -> Option<&str>
Get the first non-root component of this path as a str
Returns None if the path is empty, or consists only of the root prefix.
pub fn split_first(&self) -> Option<(&str, &Path)>
pub fn split_first(&self) -> Option<(&str, &Path)>
Splits this path on the first non-root component, returning it and a new Path of the remaining components.
Returns None if there are no components to split
pub fn split_last(&self) -> Option<(&str, &Path)>
pub fn split_last(&self) -> Option<(&str, &Path)>
Splits this path on the last component, returning it and a new Path of the remaining components.
Returns None if there are no components to split
pub fn is_kernel_path(&self) -> bool
pub fn is_kernel_path(&self) -> bool
Returns true if this path is for the root kernel module.
pub fn is_in_kernel(&self) -> bool
pub fn is_in_kernel(&self) -> bool
Returns true if this path is for the root kernel module or an item in it
pub fn is_exec_path(&self) -> bool
pub fn is_exec_path(&self) -> bool
Returns true if this path is for an executable module.
pub fn is_in_exec(&self) -> bool
pub fn is_in_exec(&self) -> bool
Returns true if this path is for the executable module or an item in it
pub fn starts_with<Prefix>(&self, prefix: &Prefix) -> bool
pub fn starts_with<Prefix>(&self, prefix: &Prefix) -> bool
Returns true if the current path, sans root component, starts with prefix
The matching semantics of Prefix depend on the implementation of StartsWith<Prefix>,
in particular, if Prefix is str, then the prefix is matched against the first non-root
component of self, regardless of whether the string contains path delimiters (i.e. ::).
See the StartsWith trait for more details.
pub fn starts_with_exactly<Prefix>(&self, prefix: &Prefix) -> bool
pub fn starts_with_exactly<Prefix>(&self, prefix: &Prefix) -> bool
Returns true if the current path, including root component, starts with prefix
The matching semantics of Prefix depend on the implementation of StartsWith<Prefix>,
in particular, if Prefix is str, then the prefix is matched against the first component
of self, regardless of whether the string contains path delimiters (i.e. ::).
See the StartsWith trait for more details.
pub fn strip_prefix<'a>(&'a self, prefix: &Path) -> Option<&'a Path>
pub fn strip_prefix<'a>(&'a self, prefix: &Path) -> Option<&'a Path>
Strips prefix from self, or returns None if self does not start with prefix.
NOTE: Prefixes must be exact, i.e. if you call path.strip_prefix(prefix) and path is
relative but prefix is absolute, then this will return None. The same is true if path
is absolute and prefix is relative.
pub fn join<P>(&self, other: &P) -> PathBuf
pub fn join<P>(&self, other: &P) -> PathBuf
Create an owned PathBuf with path adjoined to self.
If path is absolute, it replaces the current path.
The semantics of how other is joined to self in the resulting path depends on the
implementation of Join used. The implementation for Path and PathBuf joins all
components of other to self; while the implementation for [prim@str], string-like values, and identifiers/symbols joins just a single component. You must be careful to ensure that if you are passing a string here, that you specifically want to join it as a single component, or the resulting path may be different than you expect. It is recommended that you use Path::new(&string)` if you want to be explicit about treating a string-like value
as a multi-component path.
pub fn canonicalize(&self) -> Result<PathBuf, PathError>
pub fn canonicalize(&self) -> Result<PathBuf, PathError>
Canonicalize this path by ensuring that all components are in canonical form.
Canonical form dictates that:
- A component is quoted only if it requires quoting, and unquoted otherwise
- Is made absolute if relative and the first component is $kernel or $exec
Returns Err if the path is invalid