TypeAlias

Struct TypeAlias 

pub struct TypeAlias {
    pub visibility: Visibility,
    pub name: Ident,
    pub ty: TypeExpr,
    /* private fields */
}
A TypeAlias represents a named Type.

Type aliases correspond to type declarations in Miden Assembly source files. They are called aliases, rather than declarations, as the type system for Miden Assembly is structural, rather than nominal, and so two aliases with the same underlying type are considered equivalent.

Fields

visibility: Visibility

The visibility of this type alias

name: Ident

The name of this type alias

ty: TypeExpr

The concrete underlying type

Implementations



impl TypeAlias

pub fn new(visibility: Visibility, name: Ident, ty: TypeExpr) -> TypeAlias

Create a new type alias from a name and type

pub fn with_docs(self, docs: Option<Span<String>>) -> TypeAlias

Adds documentation to this type alias

pub fn with_span(self, span: SourceSpan) -> TypeAlias

Override the default source span

pub fn set_span(&mut self, span: SourceSpan)

Set the source span

pub fn docs(&self) -> Option<Span<&str>>

Returns the documentation associated with this item.

pub fn name(&self) -> &Ident

Get the name of this type alias

pub const fn visibility(&self) -> Visibility

Get the visibility of this type alias