ImmU16

Type Alias ImmU16 

pub type ImmU16 = Immediate<u16>;
A 16-bit unsigned immediate

Aliased Type

pub enum ImmU16 {
    Value(Span<u16>),
    Constant(Ident),
}

Variants



Value(Span<u16>)

A literal integer value, either decimal or hex-encoded



Constant(Ident)

A constant identifier

This must refer to a constant definition in the current module.

All immediates of this type are folded to Value during semantic analysis, once all constant definitions are evaluated.