Enum AddressSpace
pub enum AddressSpace {
Byte,
Element,
}Expand description
The address space a pointer address is evaluated in.
Variants
Byte
The pointer address is evaluated as a byte address.
This is the default unit type for pointers in HIR.
Element
The pointer address is evaluated as an element address.
This is the unit type for native Miden VM addresses.
All byte-addressable pointers must be converted to element pointers at runtime before loading/storing memory.