Struct PointerType
pub struct PointerType {
pub addrspace: AddressSpace,
pub pointee: Type,
}Expand description
A pointer to an object in memory
Fields
addrspace: AddressSpaceThe address space used by pointers of this type.
pointee: TypeThe type of value located at the pointed-to address
Implementations
impl PointerType
impl PointerType
pub fn new(pointee: Type) -> PointerType
pub fn new(pointee: Type) -> PointerType
Create a new byte-addressable pointer type to pointee
pub fn new_with_address_space(
pointee: Type,
addrspace: AddressSpace,
) -> PointerType
pub fn new_with_address_space( pointee: Type, addrspace: AddressSpace, ) -> PointerType
Create a new pointer type to pointee in addrspace
pub fn addrspace(&self) -> AddressSpace
pub fn addrspace(&self) -> AddressSpace
Returns the address space of this pointer type
pub fn is_byte_pointer(&self) -> bool
pub fn is_byte_pointer(&self) -> bool
Returns true if this pointer type represents a byte pointer