Struct StructType
pub struct StructType { /* private fields */ }Expand description
This represents a structured aggregate type
Implementations
impl StructType
impl StructType
pub fn new<I>(fields: I) -> StructType
pub fn new<I>(fields: I) -> StructType
Create a new struct with default representation, i.e. a struct with representation of
TypeRepr::Packed(1).
pub fn named<I>(name: Arc<str>, fields: I) -> StructType
pub fn named<I>(name: Arc<str>, fields: I) -> StructType
Create a new struct with default representation, i.e. a struct with representation of
TypeRepr::Packed(1).
pub fn new_with_repr<I>(repr: TypeRepr, fields: I) -> StructType
pub fn new_with_repr<I>(repr: TypeRepr, fields: I) -> StructType
Create a new struct with the given representation.
This function will panic if the rules of the given representation are violated.
pub fn from_parts<I>(
name: Option<Arc<str>>,
repr: TypeRepr,
fields: I,
) -> StructType
pub fn from_parts<I>( name: Option<Arc<str>>, repr: TypeRepr, fields: I, ) -> StructType
Create a new struct from the given name, repr, and fields.
This function will panic if the rules of the given representation are violated.
pub fn min_alignment(&self) -> usize
pub fn min_alignment(&self) -> usize
Get the minimum alignment for this struct
pub fn size(&self) -> usize
pub fn size(&self) -> usize
Get the total size in bytes required to hold this struct, including alignment padding
pub fn get(&self, index: usize) -> &StructField
pub fn get(&self, index: usize) -> &StructField
Get the struct field at index, relative to declaration order.
pub fn fields(&self) -> &[StructField]
pub fn fields(&self) -> &[StructField]
Get the struct fields as a slice