Struct Library
pub struct Library { /* private fields */ }Expand description
Represents a library where all modules were compiled into a MastForest.
A library exports a set of one or more procedures. Currently, all exported procedures belong to the same top-level namespace.
Implementations
impl Library
Constructors
impl Library
Constructors
pub fn new(
mast_forest: Arc<MastForest>,
exports: BTreeMap<Arc<Path>, LibraryExport>,
) -> Result<Library, LibraryError>
pub fn new( mast_forest: Arc<MastForest>, exports: BTreeMap<Arc<Path>, LibraryExport>, ) -> Result<Library, LibraryError>
pub fn with_advice_map(self, advice_map: AdviceMap) -> Library
pub fn with_advice_map(self, advice_map: AdviceMap) -> Library
Produces a new library with the existing MastForest and where all key/values in the
provided advice map are added to the internal advice map.
impl Library
Public accessors
impl Library
Public accessors
pub fn digest(&self) -> &Word
pub fn digest(&self) -> &Word
Returns the [Word] representing the content hash of this library
pub fn exports(&self) -> impl Iterator<Item = &LibraryExport>
pub fn exports(&self) -> impl Iterator<Item = &LibraryExport>
Returns the fully qualified name and metadata of all procedures exported by the library.
pub fn num_exports(&self) -> usize
pub fn num_exports(&self) -> usize
Returns the number of exports in this library.
pub fn get_export_node_id(&self, path: impl AsRef<Path>) -> MastNodeId
pub fn get_export_node_id(&self, path: impl AsRef<Path>) -> MastNodeId
Returns a MAST node ID associated with the specified exported procedure.
Panics
Panics if the specified procedure is not exported from this library.
pub fn is_reexport(&self, path: impl AsRef<Path>) -> bool
pub fn is_reexport(&self, path: impl AsRef<Path>) -> bool
Returns true if the specified exported procedure is re-exported from a dependency.
pub fn mast_forest(&self) -> &Arc<MastForest>
pub fn mast_forest(&self) -> &Arc<MastForest>
Returns a reference to the inner MastForest.
pub fn get_procedure_root_by_path(&self, path: impl AsRef<Path>) -> Option<Word>
pub fn get_procedure_root_by_path(&self, path: impl AsRef<Path>) -> Option<Word>
Returns the digest of the procedure with the specified name, or None if it was not found
in the library or its library path is malformed.
impl Library
Conversions
impl Library
Conversions
pub fn module_infos(&self) -> impl Iterator<Item = ModuleInfo>
pub fn module_infos(&self) -> impl Iterator<Item = ModuleInfo>
Returns an iterator over the module infos of the library.
impl Library
impl Library
pub const LIBRARY_EXTENSION: &'static str = "masl"
pub const LIBRARY_EXTENSION: &'static str = "masl"
File extension for the Assembly Library.
pub fn write_to_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
pub fn write_to_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
Write the library to a target file
NOTE: It is up to the caller to use the correct file extension, but there is no
specific requirement that the extension be set, or the same as
Self::LIBRARY_EXTENSION.
pub fn deserialize_from_file( path: impl AsRef<Path>, ) -> Result<Library, DeserializationError>