Struct ModuleInfo
pub struct ModuleInfo { /* private fields */ }Implementations
impl ModuleInfo
impl ModuleInfo
pub fn new(path: Arc<Path>) -> ModuleInfo
pub fn new(path: Arc<Path>) -> ModuleInfo
Returns a new ModuleInfo instantiated library path.
pub fn add_procedure(
&mut self,
name: ProcedureName,
digest: Word,
signature: Option<Arc<FunctionType>>,
attributes: AttributeSet,
)
pub fn add_procedure( &mut self, name: ProcedureName, digest: Word, signature: Option<Arc<FunctionType>>, attributes: AttributeSet, )
Adds a procedure to the module.
pub fn add_constant(&mut self, name: Ident, value: ConstantValue)
pub fn add_constant(&mut self, name: Ident, value: ConstantValue)
Adds a constant to the module.
pub fn num_procedures(&self) -> usize
pub fn num_procedures(&self) -> usize
Returns the number of procedures in the module.
pub fn get_item_by_index(&self, index: ItemIndex) -> Option<&ItemInfo>
pub fn get_item_by_index(&self, index: ItemIndex) -> Option<&ItemInfo>
Returns the ItemInfo of the item at the provided index, if any.
pub fn get_item_index_by_name(&self, name: &str) -> Option<ItemIndex>
pub fn get_item_index_by_name(&self, name: &str) -> Option<ItemIndex>
Returns the ItemIndex of an item by its local name
pub fn get_procedure_digest_by_name(&self, name: &str) -> Option<Word>
pub fn get_procedure_digest_by_name(&self, name: &str) -> Option<Word>
Returns the digest of the procedure with the provided name, if any.
pub fn items(&self) -> impl ExactSizeIterator
pub fn items(&self) -> impl ExactSizeIterator
Returns an iterator over the items in the module with their corresponding item index in the module.
pub fn procedures(&self) -> impl Iterator<Item = (ItemIndex, &ProcedureInfo)>
pub fn procedures(&self) -> impl Iterator<Item = (ItemIndex, &ProcedureInfo)>
Returns an iterator over the procedure infos in the module with their corresponding item index in the module.
pub fn procedure_digests(&self) -> impl Iterator<Item = Word>
pub fn procedure_digests(&self) -> impl Iterator<Item = Word>
Returns an iterator over the MAST roots of procedures defined in this module.
pub fn constants(&self) -> impl Iterator<Item = (ItemIndex, &ConstantInfo)>
pub fn constants(&self) -> impl Iterator<Item = (ItemIndex, &ConstantInfo)>
Access the constants associated with this module