Struct ProcedureExport
pub struct ProcedureExport {
pub node: MastNodeId,
pub path: Arc<Path>,
pub signature: Option<FunctionType>,
pub attributes: AttributeSet,
}Fields
node: MastNodeIdThe id of the MAST root node of the exported procedure
path: Arc<Path>The fully-qualified path of the exported procedure
signature: Option<FunctionType>The type signature of the exported procedure, if known
attributes: AttributeSetImplementations
impl ProcedureExport
impl ProcedureExport
pub fn new(node: MastNodeId, path: Arc<Path>) -> ProcedureExport
pub fn new(node: MastNodeId, path: Arc<Path>) -> ProcedureExport
Create a new ProcedureExport representing the export of node with path
pub fn with_signature(self, signature: FunctionType) -> ProcedureExport
pub fn with_signature(self, signature: FunctionType) -> ProcedureExport
Specify the type signature and ABI of this export
pub fn with_attributes(self, attrs: AttributeSet) -> ProcedureExport
pub fn with_attributes(self, attrs: AttributeSet) -> ProcedureExport
Specify the set of attributes attached to this export