pub enum LinkStatus {
Unlinked,
PartiallyLinked,
Linked,
}Expand description
Represents the current status of a symbol in the state of the Linker
Variants
Unlinked
The module or item has not been visited by the linker
PartiallyLinked
The module or item has been visited by the linker, but still refers to one or more unresolved symbols.
Linked
The module or item has been visited by the linker, and is fully linked and resolved