pub struct ResolverCache {
pub types: BTreeMap<GlobalItemIndex, Type>,
pub constants: BTreeMap<GlobalItemIndex, ConstantValue>,
pub evaluating_constants: BTreeMap<GlobalItemIndex, SourceSpan>,
}Expand description
A ResolverCache is used to cache resolutions of type and constant expressions to concrete values that contain no references to other symbols. Since these resolutions can be expensive to compute, and often represent items which are referenced multiple times, we cache them to avoid recomputing the same information over and over again.
Fields
types: BTreeMap<GlobalItemIndex, Type>constants: BTreeMap<GlobalItemIndex, ConstantValue>evaluating_constants: BTreeMap<GlobalItemIndex, SourceSpan>Trait Implementations
Sourceimpl Default for ResolverCache
impl Default for ResolverCache
Sourcefn default() -> ResolverCache
fn default() -> ResolverCache
Returns the “default value” for a type. Read more