pub struct Symbol { /* private fields */ }Expand description
A Symbol is a named, linkable item defined within a module.
Implementations
Sourceimpl Symbol
impl Symbol
Sourcepub fn new(
name: Ident,
visibility: Visibility,
status: LinkStatus,
item: SymbolItem,
) -> Self
pub fn new( name: Ident, visibility: Visibility, status: LinkStatus, item: SymbolItem, ) -> Self
Create a new Symbol.
Sourcepub fn visibility(&self) -> Visibility
pub fn visibility(&self) -> Visibility
Get the external visibility of this symbol
Sourcepub fn item(&self) -> &SymbolItem
pub fn item(&self) -> &SymbolItem
Get the item associated with this symbol
Sourcepub fn status(&self) -> LinkStatus
pub fn status(&self) -> LinkStatus
Get the current link status of this symbol
Sourcepub fn set_status(&self, status: LinkStatus)
pub fn set_status(&self, status: LinkStatus)
Set the link status of this symbol
Sourcepub fn is_unlinked(&self) -> bool
pub fn is_unlinked(&self) -> bool
Returns true if this symbol has not yet been visited by the linker.
Sourcepub fn is_procedure(&self) -> bool
pub fn is_procedure(&self) -> bool
Returns true if this symbol represents a procedure definition.