pub struct SymbolResolutionContext {
pub span: SourceSpan,
pub module: ModuleIndex,
pub kind: Option<InvokeKind>,
}Expand description
Represents the context in which symbols should be resolved.
A symbol may be resolved in different ways depending on where it is being referenced from, and how it is being referenced.
Fields
span: SourceSpanThe source span of the caller/referent
module: ModuleIndexThe “where”, i.e. index of the caller/referent’s module node in the Linker module graph.
kind: Option<InvokeKind>The “how”, i.e. how the symbol is being referenced/invoked.
This is primarily relevant for procedure invocations, particularly syscalls, as “local” names resolve in the kernel module, not in the caller’s module. Non-procedure symbols are always pure references.
Implementations
Sourceimpl SymbolResolutionContext
impl SymbolResolutionContext
pub fn in_syscall(&self) -> bool