Struct JoinNode
pub struct JoinNode { /* private fields */ }Expand description
A Join node describe sequential execution. When the VM encounters a Join node, it executes the first child first and the second child second.
Implementations
impl JoinNode
Constants
impl JoinNode
Constants
pub const DOMAIN: Felt
pub const DOMAIN: Felt
The domain of the join block (used for control block hashing).
impl JoinNode
Public accessors
impl JoinNode
Public accessors
pub fn first(&self) -> MastNodeId
pub fn first(&self) -> MastNodeId
Returns the ID of the node that is to be executed first.
pub fn second(&self) -> MastNodeId
pub fn second(&self) -> MastNodeId
Returns the ID of the node that is to be executed after the execution of the program defined by the first node completes.