Struct LoopNode
pub struct LoopNode { /* private fields */ }Expand description
A Loop node defines condition-controlled iterative execution. When the VM encounters a Loop node, it will keep executing the body of the loop as long as the top of the stack is `1``.
The loop is exited when at the end of executing the loop body the top of the stack is 0``. If the top of the stack is neither 0nor1` when the condition is checked, the execution
fails.
Implementations
impl LoopNode
Constants
impl LoopNode
Constants
pub const DOMAIN: Felt
pub const DOMAIN: Felt
The domain of the loop node (used for control block hashing).
impl LoopNode
impl LoopNode
pub fn body(&self) -> MastNodeId
pub fn body(&self) -> MastNodeId
Returns the ID of the node presenting the body of the loop.