Struct MastNodeFingerprint
pub struct MastNodeFingerprint { /* private fields */ }Expand description
Represents the hash used to test for equality between crate::mast::MastNodes.
The decorator root will be None if and only if there are no decorators attached to the node,
and all children have no decorator roots (meaning that there are no decorators in all the
descendants).
Implementations
impl MastNodeFingerprint
Constructors
impl MastNodeFingerprint
Constructors
pub fn new(mast_root: Word) -> MastNodeFingerprint
pub fn new(mast_root: Word) -> MastNodeFingerprint
Creates a new MastNodeFingerprint from the given MAST root with an empty decorator root.
pub fn with_decorator_root(
mast_root: Word,
decorator_root: Digest<32>,
) -> MastNodeFingerprint
pub fn with_decorator_root( mast_root: Word, decorator_root: Digest<32>, ) -> MastNodeFingerprint
Creates a new MastNodeFingerprint from the given MAST root and the given
DecoratorFingerprint.
impl MastNodeFingerprint
Accessors
impl MastNodeFingerprint
Accessors
pub fn mast_root(&self) -> &Word