pub struct Procedure { /* private fields */ }Expand description
A compiled Miden Assembly procedure, consisting of MAST info and basic metadata.
Procedure metadata includes:
- Fully-qualified path of the procedure in Miden Assembly (if known).
- Number of procedure locals to allocate.
- The visibility of the procedure (e.g. public/private/syscall)
- The set of MAST roots invoked by this procedure.
- The original source span and file of the procedure (if available).
Implementations
Sourceimpl Procedure
Public accessors
impl Procedure
Public accessors
Sourcepub fn path(&self) -> &Arc<Path>
pub fn path(&self) -> &Arc<Path>
Returns a reference to the fully-qualified name of this procedure
Sourcepub const fn is_syscall(&self) -> bool
pub const fn is_syscall(&self) -> bool
Returns true if this procedure is a syscallable procedure
Sourcepub fn visibility(&self) -> Visibility
pub fn visibility(&self) -> Visibility
Returns the visibility of this procedure as expressed in the original source code
Sourcepub fn module(&self) -> &Path
pub fn module(&self) -> &Path
Returns a reference to the fully-qualified module path of this procedure
Sourcepub fn signature(&self) -> Option<Arc<FunctionType>>
pub fn signature(&self) -> Option<Arc<FunctionType>>
Returns a reference to the type signature of this procedure
Sourcepub fn num_locals(&self) -> u32
pub fn num_locals(&self) -> u32
Returns the number of memory locals reserved by the procedure.
Sourcepub fn body_node_id(&self) -> MastNodeId
pub fn body_node_id(&self) -> MastNodeId
Returns a reference to the MAST node ID of this procedure.