pub struct ProcedureContext { /* private fields */ }Expand description
Information about a procedure currently being compiled.
Implementations
Sourceimpl ProcedureContext
Constructors
impl ProcedureContext
Constructors
pub fn new( gid: GlobalItemIndex, is_program_entrypoint: bool, path: Arc<Path>, visibility: Visibility, signature: Option<Arc<FunctionType>>, is_kernel: bool, source_manager: Arc<dyn SourceManager>, ) -> Self
Sourcepub fn with_num_locals(self, num_locals: u16) -> Self
pub fn with_num_locals(self, num_locals: u16) -> Self
Sets the number of locals to allocate for the procedure.
pub fn with_span(self, span: SourceSpan) -> Self
Sourceimpl ProcedureContext
Public accessors
impl ProcedureContext
Public accessors
pub fn id(&self) -> GlobalItemIndex
pub fn is_program_entrypoint(&self) -> bool
pub fn path(&self) -> &Arc<Path>
pub fn signature(&self) -> Option<Arc<FunctionType>>
pub fn set_signature(&mut self, signature: Option<Arc<FunctionType>>)
pub fn num_locals(&self) -> u16
pub fn module(&self) -> &Path
pub fn source_manager(&self) -> &dyn SourceManager
Sourceimpl ProcedureContext
State mutators
impl ProcedureContext
State mutators
Sourcepub fn into_procedure(
self,
mast_root: Word,
mast_node_id: MastNodeId,
) -> Procedure
pub fn into_procedure( self, mast_root: Word, mast_node_id: MastNodeId, ) -> Procedure
Transforms this procedure context into a Procedure.
The passed-in mast_root defines the MAST root of the procedure’s body while
mast_node_id specifies the ID of the procedure’s body node in the MAST forest in
which the procedure is defined. Note that if the procedure is re-exported (i.e., the body
of the procedure is defined in some other MAST forest) mast_node_id will point to a
single External node.
`mast_root` and `mast_node_id` must be consistent. That is, the node located in the MAST
forest under `mast_node_id` must have the digest equal to the `mast_root`.