pub struct ProjectAssembler<'a, S: PackageCache> { /* private fields */ }Implementations
Sourceimpl<'a, S> ProjectAssembler<'a, S>where
S: PackageCache,
impl<'a, S> ProjectAssembler<'a, S>where
S: PackageCache,
pub fn with_source_provider( &mut self, provider: impl ProjectSourceProvider + 'static, ) -> &mut Self
Sourcepub fn project(&self) -> &ProjectPackage
pub fn project(&self) -> &ProjectPackage
Get the project being assembled
Sourcepub fn assemble(
&mut self,
target_selector: ProjectTargetSelector<'_>,
profile_name: &str,
) -> Result<Arc<MastPackage>, Report>
pub fn assemble( &mut self, target_selector: ProjectTargetSelector<'_>, profile_name: &str, ) -> Result<Arc<MastPackage>, Report>
Assemble a target of the current project matching target_selector, using the configuration
under the profile profile_name.
Returns an error if:
target_selectorcannot find a matching target in the current projectprofile_nameis not a profile defined in this project- An error occurs during assembly of the project or one of its dependencies
- Assembly was interrupted by a source provider for the project or one of its dependencies
Sourcepub fn assemble_interruptible(
&mut self,
target_selector: ProjectTargetSelector<'_>,
profile_name: &str,
) -> Result<ControlFlow<AssemblyInterrupted, Arc<MastPackage>>, Report>
pub fn assemble_interruptible( &mut self, target_selector: ProjectTargetSelector<'_>, profile_name: &str, ) -> Result<ControlFlow<AssemblyInterrupted, Arc<MastPackage>>, Report>
Like Self::assemble, but allows for assembly to be interrupted by source providers
early.
Returns ControlFlow representing whether assembly should break early (i.e. it was
interrupted), or continue as normal (i.e. it succeeded, and a package was produced).
When assembly is interrupted early, a AssemblyInterrupted value is returned via
ControlFlow::Break, identifying what package (and target) caused the interruption, and
what role that package/target played in assembly of the root selected target.
Returns an error if:
target_selectorcannot find a matching target in the current projectprofile_nameis not a profile defined in this project- An error occurs during assembly of the project or one of its dependencies
Sourcepub fn assemble_source_package(
&mut self,
package_id: PackageId,
project: Arc<ProjectPackage>,
target: &Target,
profile_name: &str,
package_role: InterruptedTargetRole,
required_lib: Option<ResolvedPackage>,
sources: Option<ProjectSourceInputs>,
source_provenance: Option<ProjectSourceProvenanceInputs>,
cache: &mut BTreeMap<PackageId, ResolvedPackage>,
) -> Result<ControlFlow<AssemblyInterrupted, ResolvedPackage>, Report>
pub fn assemble_source_package( &mut self, package_id: PackageId, project: Arc<ProjectPackage>, target: &Target, profile_name: &str, package_role: InterruptedTargetRole, required_lib: Option<ResolvedPackage>, sources: Option<ProjectSourceInputs>, source_provenance: Option<ProjectSourceProvenanceInputs>, cache: &mut BTreeMap<PackageId, ResolvedPackage>, ) -> Result<ControlFlow<AssemblyInterrupted, ResolvedPackage>, Report>
This is a low-level utility function of the project assembly infrastructure for assembling a project target whose sources and source provenance may have already been computed by the caller.
This API supports early interruption by source providers, represented by the ControlFlow
value which is returned. The AssemblyInterrupted value carried in the Break variant
indicates the package/target which was interrupted, and the role that target played in
assembly of the provided project and target.
In almost all cases you should prefer to use ProjectAssembler::assemble or
ProjectAssembler::assemble_interruptible instead.
Callers are required to uphold the following invariants:
package_idmust be the package identifier forprojectin the current dependency graphtargetmust be a target extracted fromprojectrequired_libmust be set if assembly oftargetwould depend on another target of the same project (i.e. an executable target implicitly depends on the library target).
It is invalid to provide source_provenance without sources - doing so will trigger an
assertion.