Enum Pattern
pub enum Pattern {
Literal(Cow<'static, str>),
Regex(Regex),
}Expand description
Represents a pattern for matching text abstractly for use in asserting contents of complex diagnostics
Variants
Literal(Cow<'static, str>)
Searches for an exact match of the given literal in the input string
Regex(Regex)
Searches for a match of the given regular expression in the input string
Implementations
impl Pattern
impl Pattern
pub fn regex(pattern: impl AsRef<str>) -> Pattern
pub fn regex(pattern: impl AsRef<str>) -> Pattern
Construct a Pattern representing the given regular expression
pub fn assert_match(&self, input: impl AsRef<str>)
pub fn assert_match(&self, input: impl AsRef<str>)
Assert that this pattern matches input.
This behaves like assert_eq! or assert_matches!, i.e. it
will produce a helpful panic message on failure that renders
the difference between what the pattern expected, and what
it actually was matched against.
pub fn assert_match_with_context(
&self,
input: impl AsRef<str>,
context: impl AsRef<str>,
)
pub fn assert_match_with_context( &self, input: impl AsRef<str>, context: impl AsRef<str>, )
Like Pattern::assert_match, but renders additional context in the case of failure to aid in troubleshooting.