Struct ModuleParser
pub struct ModuleParser { /* private fields */ }Expand description
This is a wrapper around the lower-level parser infrastructure which handles orchestrating all of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.
Implementations
impl ModuleParser
impl ModuleParser
pub fn new(kind: ModuleKind) -> ModuleParser
pub fn new(kind: ModuleKind) -> ModuleParser
Construct a new parser for the given kind of ast::Module.
pub fn set_warnings_as_errors(&mut self, yes: bool)
pub fn set_warnings_as_errors(&mut self, yes: bool)
Configure this parser so that any warning diagnostics are promoted to errors.
pub fn parse(
&mut self,
path: impl AsRef<Path>,
source: Arc<SourceFile>,
source_manager: Arc<dyn SourceManager>,
) -> Result<Box<Module>, Report>
pub fn parse( &mut self, path: impl AsRef<Path>, source: Arc<SourceFile>, source_manager: Arc<dyn SourceManager>, ) -> Result<Box<Module>, Report>
Parse a ast::Module from source, and give it the provided path.
pub fn parse_file<N, P>(
&mut self,
name: N,
path: P,
source_manager: Arc<dyn SourceManager>,
) -> Result<Box<Module>, Report>
pub fn parse_file<N, P>( &mut self, name: N, path: P, source_manager: Arc<dyn SourceManager>, ) -> Result<Box<Module>, Report>
Parse a ast::Module, name, from path.