Struct WordValue
pub struct WordValue(pub [Felt; 4]);Tuple Fields
0: [Felt; 4]Trait Implementations
impl Arbitrary for WordValue
Available on crate feature arbitrary only.
impl Arbitrary for WordValue
Available on crate feature
arbitrary only.type Parameters = ()
type Parameters = ()
The type of parameters that
arbitrary_with accepts for configuration
of the generated Strategy. Parameters must implement Default.fn arbitrary_with(
_args: <WordValue as Arbitrary>::Parameters,
) -> <WordValue as Arbitrary>::Strategy
fn arbitrary_with( _args: <WordValue as Arbitrary>::Parameters, ) -> <WordValue as Arbitrary>::Strategy
impl Deserializable for WordValue
impl Deserializable for WordValue
fn read_from<R>(source: &mut R) -> Result<WordValue, DeserializationError>where
R: ByteReader,
fn read_from<R>(source: &mut R) -> Result<WordValue, DeserializationError>where
R: ByteReader,
Reads a sequence of bytes from the provided
source, attempts to deserialize these bytes
into Self, and returns the result. Read morefn min_serialized_size() -> usize
fn min_serialized_size() -> usize
Returns the minimum serialized size for one instance of this type. Read more
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes_with_budget(
bytes: &[u8],
budget: usize,
) -> Result<Self, DeserializationError>
fn read_from_bytes_with_budget( bytes: &[u8], budget: usize, ) -> Result<Self, DeserializationError>
Deserializes
Self from bytes with a byte budget limit. Read moreimpl<'de> Deserialize<'de> for WordValue
impl<'de> Deserialize<'de> for WordValue
fn deserialize<__D>(
__deserializer: __D,
) -> Result<WordValue, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<WordValue, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Ord for WordValue
impl Ord for WordValue
impl PartialOrd for WordValue
impl PartialOrd for WordValue
impl PrettyPrint for WordValue
impl PrettyPrint for WordValue
fn to_pretty_string(&self) -> String
fn to_pretty_string(&self) -> String
fn pretty_print(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn pretty_print(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Pretty-print this object to the given core::fmt::Formatter. Read more
impl Serializable for WordValue
impl Serializable for WordValue
fn write_into<W>(&self, target: &mut W)where
W: ByteWriter,
fn write_into<W>(&self, target: &mut W)where
W: ByteWriter,
Serializes
self into bytes and writes these bytes into the target.fn get_size_hint(&self) -> usize
fn get_size_hint(&self) -> usize
Returns an estimate of how many bytes are needed to represent self. Read more
impl Serialize for WordValue
impl Serialize for WordValue
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for WordValue
impl Eq for WordValue
impl StructuralPartialEq for WordValue