pub struct TestContext { /* private fields */ }Expand description
A TestContext provides common functionality for all tests which interact with an Assembler.
It is used by constructing it with TestContext::default(), which will initialize the
diagnostic reporting infrastructure, and construct a default Assembler instance for you. You
can then optionally customize the context, or start invoking any of its test helpers.
Some of the assertion macros defined above require a TestContext, so be aware of that.
Implementations
Sourceimpl TestContext
impl TestContext
pub fn new() -> Self
pub fn source_manager(&self) -> Arc<dyn SourceManager>
Sourcepub fn parse_forms(&self, source: Arc<SourceFile>) -> Result<Vec<Form>, Report>
pub fn parse_forms(&self, source: Arc<SourceFile>) -> Result<Vec<Form>, Report>
Sourcepub fn parse_program(&self, source: impl Parse) -> Result<Box<Module>, Report>
pub fn parse_program(&self, source: impl Parse) -> Result<Box<Module>, Report>
Parse the given source file into an executable Module.
This runs semantic analysis, and the returned module is guaranteed to be syntactically valid.
Sourcepub fn parse_kernel(&self, source: impl Parse) -> Result<Box<Module>, Report>
pub fn parse_kernel(&self, source: impl Parse) -> Result<Box<Module>, Report>
Parse the given source file into a kernel Module.
This runs semantic analysis, and the returned module is guaranteed to be syntactically valid.
Sourcepub fn parse_module(&self, source: impl Parse) -> Result<Box<Module>, Report>
pub fn parse_module(&self, source: impl Parse) -> Result<Box<Module>, Report>
Parse the given source file into an anonymous library Module.
This runs semantic analysis, and the returned module is guaranteed to be syntactically valid.
Sourcepub fn parse_module_with_path(
&self,
path: impl AsRef<Path>,
source: impl Parse,
) -> Result<Box<Module>, Report>
pub fn parse_module_with_path( &self, path: impl AsRef<Path>, source: impl Parse, ) -> Result<Box<Module>, Report>
Parse the given source file into a library Module with the given fully-qualified path.
Sourcepub fn add_module(&mut self, module: impl Parse) -> Result<(), Report>
pub fn add_module(&mut self, module: impl Parse) -> Result<(), Report>
Add module to the Assembler constructed by this context, making it available to
other modules.
Sourcepub fn add_module_from_source(
&mut self,
path: impl AsRef<Path>,
source: impl Parse,
) -> Result<(), Report>
pub fn add_module_from_source( &mut self, path: impl AsRef<Path>, source: impl Parse, ) -> Result<(), Report>
Add a module to the Assembler constructed by this context, with the fully-qualified
name path, by parsing it from the provided source file.
This will fail if the module cannot be parsed, fails semantic analysis, or conflicts with a previously added module within the assembler.
Sourcepub fn add_library(
&mut self,
library: impl AsRef<Library>,
) -> Result<(), Report>
pub fn add_library( &mut self, library: impl AsRef<Library>, ) -> Result<(), Report>
Add the modules of library to the Assembler constructed by this context.
Sourcepub fn assemble(&self, source: impl Parse) -> Result<Program, Report>
pub fn assemble(&self, source: impl Parse) -> Result<Program, Report>
Compile a [Program] from source using the Assembler constructed by this context.
NOTE: Any modules added by, e.g. add_module, will be available to the executable
module represented in source.
Sourcepub fn assemble_library(
&self,
modules: impl IntoIterator<Item = Box<Module>>,
) -> Result<Library, Report>
pub fn assemble_library( &self, modules: impl IntoIterator<Item = Box<Module>>, ) -> Result<Library, Report>