Enum IndexedVecError
pub enum IndexedVecError {
TooManyItems,
}Expand description
Error returned when too many items are added to an IndexedVec.
Variants
TooManyItems
The number of items exceeds the maximum supported by ID type.