Enum ConstantExpr
#[repr(u8)]pub enum ConstantExpr {
Int(Span<IntValue>),
Var(Span<Arc<Path>>),
BinaryOp {
span: SourceSpan,
op: ConstantOp,
lhs: Box<ConstantExpr>,
rhs: Box<ConstantExpr>,
},
String(Ident),
Word(Span<WordValue>),
Hash(HashKind, Ident),
}Expand description
Represents a constant expression or value in Miden Assembly syntax.
Variants
Int(Span<IntValue>)
A literal [Felt] value.
Var(Span<Arc<Path>>)
A reference to another constant.
BinaryOp
An binary arithmetic operator.
String(Ident)
A plain spanned string.
Word(Span<WordValue>)
A literal [‘WordValue’].
Hash(HashKind, Ident)
A spanned string with a HashKind showing to which type of value the given string should
be hashed.
Implementations
impl ConstantExpr
impl ConstantExpr
pub fn is_value(&self) -> bool
pub fn is_value(&self) -> bool
Returns true if this expression is already evaluated to a concrete value
pub fn expect_int(&self) -> IntValue
pub fn expect_int(&self) -> IntValue
Unwrap an IntValue from this expression or panic.
This is used in places where we expect the expression to have been folded to an integer, otherwise a bug occurred.
pub fn expect_felt(&self) -> Felt
pub fn expect_felt(&self) -> Felt
Unwrap a [Felt] value from this expression or panic.
This is used in places where we expect the expression to have been folded to a felt value, otherwise a bug occurred.
pub fn expect_string(&self) -> Arc<str>
pub fn expect_string(&self) -> Arc<str>
Unwrap a Arc<str> value from this expression or panic.
This is used in places where we expect the expression to have been folded to a string value, otherwise a bug occurred.
pub fn expect_value(&self) -> ConstantValue
pub fn expect_value(&self) -> ConstantValue
Unwrap a ConstantValue from this expression or panic.
This is used in places where we expect the expression to have been folded to a concrete value, otherwise a bug occurred.
pub fn into_value(self) -> Result<ConstantValue, ConstantExpr>
pub fn into_value(self) -> Result<ConstantValue, ConstantExpr>
Try to convert this expression into a ConstantValue, if the expression is a value.
Returns Err if the expression cannot be represented as a ConstantValue.
pub fn as_value(&self) -> Option<ConstantValue>
pub fn as_value(&self) -> Option<ConstantValue>
Get the ConstantValue representation of this expression, if it is a value.
Returns None if the expression cannot be represented as a ConstantValue.
pub fn try_fold(self) -> Result<ConstantExpr, ParsingError>
pub fn try_fold(self) -> Result<ConstantExpr, ParsingError>
Attempt to fold to a single value.
This will only succeed if the expression has no references to other constants.
Errors
Returns an error if an invalid expression is found while folding, such as division by zero.
pub fn references(&self) -> Vec<Span<Arc<Path>>>
pub fn references(&self) -> Vec<Span<Arc<Path>>>
Get any references to other symbols present in this expression