Struct Variant
pub struct Variant {
pub name: Arc<str>,
pub discriminant_value: Option<u128>,
pub value: Option<Type>,
}Fields
name: Arc<str>The name of this variant
discriminant_value: Option<u128>The value of the discriminant, stored as a value of the largest valid integral type.
The value can always be safely be truncated to the actual discriminant type.
If unspecified, it is inferred from context (either derived from the variant index, or from the last discriminant with a specified value).
value: Option<Type>The type of the value representing this variant.
When None, this variant is represented solely by the discriminant, and has no distinct
value type of its own.
Implementations