Variant

Struct Variant 

pub struct Variant {
    pub name: Arc<str>,
    pub discriminant_value: Option<u128>,
    pub value: Option<Type>,
}

Fields

name: Arc<str>

The name of this variant

discriminant_value: Option<u128>

The value of the discriminant, stored as a value of the largest valid integral type.

The value can always be safely be truncated to the actual discriminant type.

If unspecified, it is inferred from context (either derived from the variant index, or from the last discriminant with a specified value).

value: Option<Type>

The type of the value representing this variant.

When None, this variant is represented solely by the discriminant, and has no distinct value type of its own.

Implementations

Source

impl Variant

pub const fn new( name: Arc<str>, ty: Type, discriminant: Option<u128>, ) -> Variant

Constructs an enum variant named name, and whose payload value is of type ty.

Callers may optionally provide an explicit discriminant value.

NOTE: Variants must have unique discriminants.

pub const fn c_like(name: Arc<str>, discriminant: Option<u128>) -> Variant

Constructs an enum variant for a C-like enumeration, providing the name and discriminant value for that variant.

C-like enum variants have no payload value, i.e. the value of the enum is the discriminant value.