pub struct SymbolResolver<'a> { /* private fields */ }Expand description
A SymbolResolver is used to resolve a procedure invocation target to its concrete definition.
Because modules can re-export/alias the procedures of modules they import, resolving the name of a procedure can require multiple steps to reach the original concrete definition of the procedure.
The SymbolResolver encapsulates the tricky details of doing this, so that users of the resolver need only provide a reference to the Linker, a name they wish to resolve, and some information about the caller necessary to determine the context in which the name should be resolved.
Implementations
Sourceimpl<'a> SymbolResolver<'a>
impl<'a> SymbolResolver<'a>
Sourcepub fn new(graph: &'a Linker) -> Self
pub fn new(graph: &'a Linker) -> Self
Create a new SymbolResolver for the provided Linker.
pub fn source_manager(&self) -> &dyn SourceManager
pub fn source_manager_arc(&self) -> Arc<dyn SourceManager>
Sourcepub fn resolve_invoke_target(
&self,
context: &SymbolResolutionContext,
target: &InvocationTarget,
) -> Result<SymbolResolution, LinkerError>
pub fn resolve_invoke_target( &self, context: &SymbolResolutionContext, target: &InvocationTarget, ) -> Result<SymbolResolution, LinkerError>
Resolve target, a possibly-resolved symbol reference, to a SymbolResolution, using
context as the context.
pub fn resolve_path( &self, context: &SymbolResolutionContext, path: Span<&Path>, ) -> Result<SymbolResolution, LinkerError>
pub fn resolve_local( &self, context: &SymbolResolutionContext, symbol: &str, ) -> Result<SymbolResolution, LinkerError>
pub fn module_path(&self, module: ModuleIndex) -> &Path
pub fn item_path(&self, item: GlobalItemIndex) -> Arc<Path>